from gpaw.mixer import Mixer
from gpaw import FermiDirac
from gpaw.poisson import PoissonSolver
from gpaw.mpi import world
from gpaw.utilities import h2gpts

if world.size == 4:
    m, n = 2, 2
elif world.size == 8:
    m, n = 4, 2
elif world.size == 16:
    m, n = 4, 4
elif world.size == 24:
    m, n = 6, 4
elif world.size == 32:
    m, n = 8, 4
elif world.size == 48:
    m, n = 6, 8
else:
    m = world.size // 2
    n = 2

def getkwargs(system, **kwargs):
    gpts = h2gpts(0.2, system.get_cell(), idiv=8)
    kwargs1 = dict(gpts=gpts,
                   xc='RPBE',
                   mode='lcao',
                   basis='dzp',
                   nbands=6 * len(system),
                   occupations=FermiDirac(0.01),
                   poissonsolver=PoissonSolver(relax='GS', eps=2e-8),
                   parallel=dict(sl_default=(m, n, 64)),
                   mixer=Mixer(0.1, 5, 50.0))
    kwargs1.update(kwargs)
    return kwargs1
